@@ -13,7 +13,7 @@ import polars as pl
 
 from cameo_claw.file import mkdir
 from cameo_claw.functional import it_mp_f
-from cameo_claw.net import requests_get_bytes
+from cameo_claw.net import requests_get_bytes, url_to_filename
 from glob import glob
 from functools import lru_cache
 
@@ -261,3 +261,13 @@ def to_csv_gz(df, target_directory, url, lst_group_by_column):
     bytesio, filename = bytesio_filename(df, url, has_header=True)
     path = f'{target_directory}{filename}{filename_tail}.csv.gz'
     return write_gzip(bytesio, path)
+
+
+def to_parquet(df, target_directory, url, lst_group_by_column):
+    mkdir(target_directory)
+    filename_tail = '_group_' + '-'.join(list(
+        map(lambda column: str(df.row(0)[df.find_idx_by_name(column)]).replace('_', '-'), lst_group_by_column)))
+    filename = url_to_filename(url)
+    path = f'{target_directory}{filename}{filename_tail}.parquet'
+    df.write_parquet(path, compression='snappy')
+    return True
