@@ -117,6 +117,9 @@ def distinct_filter_sort(bytes1, lst_distinct_column, lst_column_match, sort_col
     return df
 
 
+from fastapi.middleware.gzip import GZipMiddleware
+
+
 def fastapi_app():
     app = FastAPI(docs_url="/d", redoc_url=None, openapi_url="/o.json")
     app.add_middleware(CORSMiddleware,
@@ -124,6 +127,7 @@ def fastapi_app():
                        allow_credentials=True,
                        allow_methods=['*'],
                        allow_headers=['*'])
+    app.add_middleware(GZipMiddleware, minimum_size=1000)
     return app
 
 
