@@ -9,7 +9,7 @@ from cameo_claw.cameo_claw import it_chunk_pl
 
 from pydantic import BaseModel
 
-from cameo_claw.cameo_claw_reuse import pd_read_csv, fastapi_app, lst_demo_url
+from cameo_claw.cameo_claw_reuse import fastapi_app, lst_demo_url
 
 app = fastapi_app()
 
@@ -38,13 +38,13 @@ def it_streaming_pl(i: ItemUrlFilter):
         print('it_streaming_pl,exception:', e)
 
 
-def write_csv_header_to_gz_pd(i):
-    r = requests.get(i.lst_url[0], verify=False)
-    df = pd_read_csv(r.content)
-    bytesio_gz = BytesIO()
-    with gzip.open(bytesio_gz, 'wb') as f:
-        f.write((','.join(df.columns) + '\n').encode('utf-8'))
-    return bytesio_gz.getvalue()
+# def write_csv_header_to_gz_pd(i):
+#     r = requests.get(i.lst_url[0], verify=False)
+#     df = pd_read_csv(r.content)
+#     bytesio_gz = BytesIO()
+#     with gzip.open(bytesio_gz, 'wb') as f:
+#         f.write((','.join(df.columns) + '\n').encode('utf-8'))
+#     return bytesio_gz.getvalue()
 
 
 def write_csv_header_to_gz_pl(i):
